Core modules — summer 0.7.8 documentation

# Core modules

## ex – exception definitions

Exception classes used in summer framework. Some are suitable for inheritance.

## domain – domain model

Basic support for domain classes, including persistent domain classes.

## context – summer object container

Module `context` defines an application context (`Context` class)– a container for (business) objects, that should be available throughout the application, application layer or module.

## l10n – localization

Based on Python’s `gettext` module.